Package: DAISIEprep
Type: Package
Title: Extracts Phylogenetic Island Community Data from Phylogenetic
        Trees
Version: 1.0.1
Authors@R: c(
    person(given = "Joshua W.",
           family = "Lambert",
           email = "joshua.lambert@lshtm.ac.uk",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-5218-3046")),
    person(given = "Luis",
           family = "Valente",
           email = "luis.valente@naturalis.nl",
           role = c("aut"),
           comment = c(ORCID = "0000-0003-4247-8785")),
    person(given = "Pedro",
           family = "Santos Neves",
           role = c("aut"),
           email = "p.m.santos.neves@rug.nl",
           comment = c(ORCID = "0000-0003-2561-4677")),
    person(given = "Lizzie",
           family = "Roeble",
           email = "lizzie.roeble@naturalis.nl",
           role = c("aut"),
           comment = c(ORCID = "0000-0003-3664-4222")),
    person(given = "Theo",
           family = "Pannetier",
           email = "t.s.c.pannetier@rug.nl",
           role = c("aut"),
           comment = c(ORCID = "0000-0002-8424-3573"))
           )
Description: Extracts colonisation and branching times of island
    species to be used for analysis in the R package 'DAISIE'. It uses
    phylogenetic and endemicity data to extract the separate island colonists
    and store them.
URL: https://github.com/joshwlambert/DAISIEprep,
        https://joshwlambert.github.io/DAISIEprep/
BugReports: https://github.com/joshwlambert/DAISIEprep/issues
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 4.0)
biocViews:
Imports: methods, ape, phylobase, ggplot2, scales, ggtree, DAISIE,
        castor, tibble, rlang
Suggests: testthat (>= 3.0.0), knitr, rmarkdown, covr, diversitree,
        corHMM, tidyr, dplyr, ggimage
VignetteBuilder: knitr
Config/testthat/edition: 3
Collate: 'DAISIEprep-package.R' 'add_asr_node_states.R'
        'add_island_colonist.R' 'add_missing_species.R'
        'add_multi_missing_species.R' 'add_outgroup.R'
        'all_descendants_conspecific.R' 'any_back_colonisation.R'
        'any_outgroup.R' 'any_polyphyly.R' 'as_daisie_datatable.R'
        'benchmark.R' 'bind_colonist_to_tbl.R' 'check_phylo_data.R'
        'count_missing_species.R' 'create_daisie_data.R'
        'create_endemicity_status.R' 'create_test_phylod.R' 'data.R'
        'default_params_doc.R' 'endemicity_to_sse_states.R'
        'extract_asr_clade.R' 'extract_clade_name.R'
        'extract_endemic_clade.R' 'extract_endemic_singleton.R'
        'extract_island_species.R' 'extract_multi_tip_species.R'
        'extract_nonendemic.R' 'extract_species_asr.R'
        'extract_species_min.R' 'extract_stem_age.R'
        'extract_stem_age_asr.R' 'extract_stem_age_genus.R'
        'extract_stem_age_min.R' 'get_endemic_species.R'
        'is_back_colonisation.R' 'is_duplicate_colonist.R'
        'is_identical_island_tbl.R' 'is_multi_tip_species.R'
        'island_colonist-class.R' 'island_colonist-accessors.R'
        'island_tbl-class.R' 'island_tbl-accessors.R'
        'island_tbl-methods.R' 'multi_extract_island_species.R'
        'multi_island_tbl-class.R' 'multi_island_tbl-methods.R'
        'plot_colonisation.R' 'plot_performance.R' 'plot_phylod.R'
        'plot_sensitivity.R' 'print-methods.R' 'read_performance.R'
        'read_sensitivity.R' 'rm_duplicate_island_species.R'
        'rm_island_colonist.R' 'rm_multi_missing_species.R'
        'rm_nonendemic_in_clade.R' 'sensitivity.R' 'translate_status.R'
        'unique_island_genera.R' 'utils.R' 'write_biogeobears_input.R'
NeedsCompilation: no
Packaged: 2025-10-30 22:15:11 UTC; lshjl15
Author: Joshua W. Lambert [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-5218-3046>),
  Luis Valente [aut] (ORCID: <https://orcid.org/0000-0003-4247-8785>),
  Pedro Santos Neves [aut] (ORCID:
    <https://orcid.org/0000-0003-2561-4677>),
  Lizzie Roeble [aut] (ORCID: <https://orcid.org/0000-0003-3664-4222>),
  Theo Pannetier [aut] (ORCID: <https://orcid.org/0000-0002-8424-3573>)
Maintainer: Joshua W. Lambert <joshua.lambert@lshtm.ac.uk>
Repository: CRAN
Date/Publication: 2025-10-30 23:50:22 UTC
Built: R 4.6.0; ; 2026-04-25 13:39:05 UTC; unix
