# Generated by roxygen2: do not edit by hand

export(add_asr_node_states)
export(add_island_colonist)
export(add_missing_species)
export(add_multi_missing_species)
export(add_outgroup)
export(all_descendants_conspecific)
export(all_endemicity_status)
export(any_back_colonisation)
export(any_outgroup)
export(any_polyphyly)
export(as_daisie_datatable)
export(benchmark)
export(bind_colonist_to_tbl)
export(check_island_colonist)
export(check_island_tbl)
export(check_multi_island_tbl)
export(check_phylo_data)
export(count_missing_species)
export(create_daisie_data)
export(create_endemicity_status)
export(create_test_phylod)
export(endemicity_to_sse_states)
export(extract_asr_clade)
export(extract_biogeobears_ancestral_states_probs)
export(extract_endemic_clade)
export(extract_endemic_singleton)
export(extract_island_species)
export(extract_multi_tip_species)
export(extract_nonendemic)
export(extract_species_asr)
export(extract_species_min)
export(extract_stem_age)
export(get_clade_name)
export(get_island_tbl)
export(get_sse_tip_states)
export(is_back_colonisation)
export(is_duplicate_colonist)
export(is_identical_island_tbl)
export(island_colonist)
export(island_tbl)
export(multi_extract_island_species)
export(multi_island_tbl)
export(plot_colonisation)
export(plot_performance)
export(plot_phylod)
export(rm_island_colonist)
export(rm_multi_missing_species)
export(select_endemicity_status)
export(sensitivity)
export(sse_states_to_endemicity)
export(translate_status)
export(unique_island_genera)
export(write_biogeobears_input)
export(write_newick_file)
export(write_phylip_biogeo_file)
exportClasses(Island_colonist)
exportClasses(Island_tbl)
exportClasses(Multi_island_tbl)
exportMethods("set_branching_times<-")
exportMethods("set_clade_name<-")
exportMethods("set_clade_type<-")
exportMethods("set_col_max_age<-")
exportMethods("set_col_time<-")
exportMethods("set_extracted_species<-")
exportMethods("set_island_tbl<-")
exportMethods("set_min_age<-")
exportMethods("set_missing_species<-")
exportMethods("set_num_phylo_used<-")
exportMethods("set_species<-")
exportMethods("set_status<-")
exportMethods(get_branching_times)
exportMethods(get_clade_name)
exportMethods(get_clade_type)
exportMethods(get_col_max_age)
exportMethods(get_col_time)
exportMethods(get_extracted_species)
exportMethods(get_island_tbl)
exportMethods(get_min_age)
exportMethods(get_missing_species)
exportMethods(get_num_phylo_used)
exportMethods(get_species)
exportMethods(get_status)
importFrom(rlang,":=")
